#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>
#include <assert.h>

#define DECIMALS_PER_DIGIT 18
#define BASE 1000000000000000000

int64_t digits_len;

struct Big_Int {
    uint64_t digits[100];
};

bool cmp_big_small(const struct Big_Int *a, const uint64_t b) {
    if (a->digits[0] != b) return false;
    for (int64_t i = 1; i < digits_len; ++i) {
        if (a->digits[i] != 0) return false;
    }
    return true;
}

struct Big_Int add(const struct Big_Int *a, const struct Big_Int *b) {
    struct Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*digits_len);

    for (int64_t i = 0; i < digits_len; ++i) {
        ret.digits[i] += a->digits[i] + b->digits[i];

        if (ret.digits[i] >= BASE) {
            ret.digits[i] -= BASE;
            if (i + 1 < digits_len) ++ret.digits[i+1];
        }
    }

    return ret;
}

void print(const struct Big_Int *a) {
    int64_t idx = digits_len - 1;
    while (a->digits[idx] == 0) --idx;
    for (; idx >= 0; --idx) printf("%018llu", a->digits[idx]);
    printf("\n");
}

bool even(const struct Big_Int *a) {
    return a->digits[0] % 2 == 0;
}

// This assumes an even base
void half(struct Big_Int *a) {
    for (int64_t i = digits_len-1; i >= 0; --i) {
        if (i > 0 && a->digits[i] % 2 == 1) a->digits[i-1] += BASE;
        a->digits[i] >>= 1;
    }
}

void dec(struct Big_Int *a) {
    int64_t first_nonzero = 0;
    while (a->digits[first_nonzero] == 0 && first_nonzero < digits_len) ++first_nonzero;
    assert(first_nonzero < digits_len);

    a->digits[first_nonzero]--;
    for (int64_t i = 0; i < first_nonzero; ++i) a->digits[i] = BASE - 1;
}

struct Big_Int mul(struct Big_Int a, struct Big_Int b) {
    Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*digits_len);

    while (!cmp_big_small(&b, 0)) {
        if (even(&b)) {
            a = add(&a, &a);
            half(&b);
        } else {
            ret = add(&ret, &a);
            dec(&b);
        }
    }

    return ret;
}

struct Big_Int big_pow(struct Big_Int a, struct Big_Int b) {
    Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*digits_len);
    ret.digits[0] = 1;

    while (!cmp_big_small(&b, 0)) {
        if (even(&b)) {
            a = mul(a, a);
            half(&b);
        } else {
            ret = mul(ret, a);
            dec(&b);
        }
    }

    return ret;
}

uint64_t get_digit(const struct Big_Int *a, uint64_t k) {
    int64_t idx = k / DECIMALS_PER_DIGIT;
    k %= DECIMALS_PER_DIGIT;

    int64_t div = 1;
    for (int i = 0; i < k; ++i) div *= 10;

    return (a->digits[idx] / div) % 10;
}

int main () {
    struct Big_Int a;
    struct Big_Int b;
    uint64_t k;

    uint64_t t;
    scanf("%llu", &t);
    for (int i = 0; i < t; ++i) {
        scanf("%llu%llu%llu", &a.digits[0], &b.digits[0], &k);

        --k;
        digits_len = k / DECIMALS_PER_DIGIT + 1;

        memset(a.digits + 1, 0, sizeof(uint64_t)*(digits_len - 1));
        memset(b.digits + 1, 0, sizeof(uint64_t)*(digits_len - 1));

        if (a.digits[0] >= BASE) {
            a.digits[0] -= BASE;
            ++a.digits[1];
        }
        if (b.digits[0] >= BASE) {
            b.digits[0] -= BASE;
            ++b.digits[1];
        }

        struct Big_Int c = big_pow(a, b);

        // print(&c);
        printf("%llu\n", get_digit(&c, k));
    }
}
