#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>
#include <assert.h>

#define DECIMALS_PER_DIGIT 18
#define BASE 1000000000000000000
#define DIGITS_CAP 56

int digits_len;

struct Big_Int {
    int64_t major;
    uint64_t digits[DIGITS_CAP];
};

void print(const struct Big_Int *a) {
    for (int i = a->major; i >= 0; --i) printf("%018llu", a->digits[i]);
    printf("\n");
}

bool cmp_big_small(const struct Big_Int *a, const uint64_t b) {
    return a->major == 0 && a->digits[0] == b;
}

void add(struct Big_Int *a, struct Big_Int *b) {
    if (a->major < b->major) a->major = b->major;
    if (a->major + 1 < digits_len) ++a->major;

    int64_t carry = 0;

    for (int64_t i = 0; i <= a->major; ++i) {
        a->digits[i] += b->digits[i] + carry;
        carry = 0;

        if (a->digits[i] >= BASE) {
            a->digits[i] -= BASE;
            carry = 1;
        }
    }

    if (a->major && a->digits[a->major] == 0) --a->major;
}

bool even(const struct Big_Int *a) {
    return a->digits[0] % 2 == 0;
}

// This assumes an even base
void half(struct Big_Int *a) {
    for (int64_t i = a->major; i >= 0; --i) {
        if (i > 0 && a->digits[i] % 2 == 1) a->digits[i-1] += BASE;
        a->digits[i] >>= 1;
    }
    if (a->major && a->digits[a->major] == 0) --a->major;
}

void dec(struct Big_Int *a) {
    int64_t first_nonzero = 0;
    while (a->digits[first_nonzero] == 0) ++first_nonzero;

    a->digits[first_nonzero]--;
    for (int64_t i = 0; i < first_nonzero; ++i) a->digits[i] = BASE - 1;

    if (a->major && a->digits[a->major] == 0) --a->major;
}

struct Big_Int mul(struct Big_Int a, struct Big_Int b) {
    Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*digits_len);
    ret.major = 0;

    while (!cmp_big_small(&b, 0)) {
        if (even(&b)) {
            add(&a, &a);
            half(&b);
        } else {
            add(&ret, &a);
            dec(&b);
        }
    }

    return ret;
}

struct Big_Int big_pow(struct Big_Int a, struct Big_Int b) {
    Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*digits_len);
    ret.major = 0;
    ret.digits[0] = 1;

    while (!cmp_big_small(&b, 0)) {
        if (even(&b)) {
            a = mul(a, a);
            half(&b);
        } else {
            ret = mul(ret, a);
            dec(&b);
        }
    }

    return ret;
}

uint64_t get_digit(const struct Big_Int *a, uint64_t k) {
    int64_t idx = k / DECIMALS_PER_DIGIT;
    k %= DECIMALS_PER_DIGIT;

    int64_t div = 1;
    for (int i = 0; i < k; ++i) div *= 10;

    return (a->digits[idx] / div) % 10;
}

int main () {
    struct Big_Int a;
    struct Big_Int b;
    uint64_t k;

    uint64_t t;
    scanf("%llu", &t);
    for (int i = 0; i < t; ++i) {
        scanf("%llu%llu%llu", &a.digits[0], &b.digits[0], &k);

        --k;
        digits_len = k / DECIMALS_PER_DIGIT + 1;

        memset(a.digits + 1, 0, sizeof(uint64_t)*(digits_len - 1));
        memset(b.digits + 1, 0, sizeof(uint64_t)*(digits_len - 1));

        if (a.digits[0] >= BASE) {
            a.digits[0] -= BASE;
            ++a.digits[1];
            a.major = 1;
        } else {
            a.major = 0;
        }
        if (b.digits[0] >= BASE) {
            b.digits[0] -= BASE;
            ++b.digits[1];
            b.major = 1;
        } else {
            b.major = 0;
        }

        struct Big_Int c = big_pow(a, b);

        printf("%llu\n", get_digit(&c, k));

        // add(&a, &b);
        // print(&a);
    }
}
